@@ -1,7 +1,7 @@
 package Complete::Bash;
 
 our $DATE = '2019-07-02'; # DATE
-our $VERSION = '0.326'; # VERSION
+our $VERSION = '0.327'; # VERSION
 
 use 5.010001;
 use strict;
@@ -640,20 +640,6 @@ sub format_completion {
 
     #warn "terminal_width=$terminal_width, column_width=".($column_width // 'undef')."\n";
 
-  SORT: {
-        # we pre-sort because we want to draw summary lines every N row
-        last unless $summary_align eq 'right';
-        my @orders = sort {
-            # XXX how does bash sort completion entries, exactly? this is still
-            # not right. bash puts -\? between --debug and --format.
-            my $e1 = lc $words[$a]; $e1 =~ s/[^A-Za-z0-9]+//;
-            my $e2 = lc $words[$b]; $e2 =~ s/[^A-Za-z0-9]+//;
-            $e1 cmp $e2;
-        } 0..$#words;
-        @words     = map { $words[$_]     } @orders;
-        @summaries = map { $summaries[$_] } @orders;
-    }
-
   FORMAT_SUMMARIES: {
         @res = @words;
         last if @words <= 1;
@@ -683,14 +669,8 @@ sub format_completion {
             #warn "max_columns=$max_columns, column_width=$column_width, max_summ_width=$max_summ_width\n";
         }
 
-        my $line_every = $ENV{COMPLETE_BASH_SUMMARY_LINE_EVERY} // 4;
         for (0..$#words) {
             my $summary = $summaries[$_];
-            if ($max_columns == 1 &&
-                    $summary_align eq 'right' && ($_+1) % $line_every == 0) {
-                $summary = ("_" x ($max_summ_width - length $summary)) .
-                    $summary;
-            }
             if (length $summary) {
                 $res[$_] = sprintf(
                     "%-${max_entry_width}s |%".
@@ -736,6 +716,8 @@ sub format_completion {
             };
 
         print CHLD_IN map { "$_:$res[$_]\n" } 0..$#res;
+        close CHLD_IN;
+
         my @res_words;
         while (<CHLD_OUT>) {
             my ($index) = /\A([0-9]+)\:/ or next;
@@ -773,7 +755,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.326 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-07-02.
+This document describes version 0.327 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-07-02.
 
 =head1 DESCRIPTION
 
@@ -1219,26 +1201,6 @@ B<fish> shell:
  --foo                        Summary about the foo option
  --schapen                Summary about the schapen option
 
-To help match the option and its corresponding summary visually, by default a
-line of underscores is drawn for every 5 lines (configurable via
-L</COMPLETE_BASH_SUMMARY_LINE_EVERY>.
-
- --bar                        Summary about the bar option
- --baz                        Summary about the baz option
- --foo                        Summary about the foo option
- --foobar   _______________Summary about the foobar option
- --lam                        Summary about the lam option
- --qux
- --quux                                    Alias for --qux
- --schapen  ______________Summary about the schapen option
-
-=head2 COMPLETE_BASH_SUMMARY_LINE_EVERY
-
-Uint. Default: 4.
-
-Relevant only when L</COMPLETE_BASH_SUMMARY_ALIGN> is set to C<right> (see its
-documentation for more detail).
-
 =head2 COMPLETE_BASH_TRACE
 
 Bool. If set to true, will produce more log statements to L<Log::ger>.
